@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# my.gpodder.org API Client
+# gpodder.net API Client
 # Copyright (C) 2009-2010 Thomas Perl
 #
 # This program is free software: you can redistribute it and/or modify
@@ -15,14 +15,26 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-__version__ = '1.2'
+__version__ = '1.3'
 __url__ = 'http://thpinfo.com/2010/mygpoclient/'
 
 # Default settings for the API client (server hostname and API version)
-HOST = 'my.gpodder.org'
-VERSION = 1
+HOST = 'gpodder.net'
+VERSION = 2
 TOPLIST_DEFAULT = 50
 
 # You can overwrite this value from your application if you want
 user_agent = 'mygpoclient/%s (+%s)' % (__version__, __url__)
 
+# Version checking
+def require_version(minimum_required):
+    """Require a minimum version of the library
+
+    Returns True if the minimum library version constraint is
+    satisfied, False otherwise. Use this to check for newer API
+    methods and changes in the public API as described in NEWS.
+    """
+    this_version = [int(x) for x in __version__.split('.')]
+    minimum_required = [int(x) for x in version.split('.')]
+    return minimum_required <= this_version
+
