@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# my.gpodder.org API Client
+# gpodder.net API Client
 # Copyright (C) 2009-2010 Thomas Perl
 #
 # This program is free software: you can redistribute it and/or modify
@@ -25,7 +25,7 @@ from mygpoclient import util
 class Locator(object):
     """URI Locator for API endpoints
 
-    This helper class abstracts the URIs for the my.gpodder.org
+    This helper class abstracts the URIs for the gpodder.net
     webservice and provides a nice facility for generating API
     URIs and checking parameters.
     """
@@ -52,9 +52,9 @@ class Locator(object):
 
         >>> locator = Locator('john')
         >>> locator.subscriptions_uri('n800')
-        'http://my.gpodder.org/subscriptions/john/n800.opml'
+        'http://gpodder.net/subscriptions/john/n800.opml'
         >>> locator.subscriptions_uri('ipod', 'txt')
-        'http://my.gpodder.org/subscriptions/john/ipod.txt'
+        'http://gpodder.net/subscriptions/john/ipod.txt'
         """
         if format not in self.SIMPLE_FORMATS:
             raise ValueError('Unsupported file format')
@@ -68,11 +68,11 @@ class Locator(object):
 
         >>> locator = Locator(None)
         >>> locator.toplist_uri()
-        'http://my.gpodder.org/toplist/50.opml'
+        'http://gpodder.net/toplist/50.opml'
         >>> locator.toplist_uri(70)
-        'http://my.gpodder.org/toplist/70.opml'
+        'http://gpodder.net/toplist/70.opml'
         >>> locator.toplist_uri(10, 'json')
-        'http://my.gpodder.org/toplist/10.json'
+        'http://gpodder.net/toplist/10.json'
         """
         if format not in self.SIMPLE_FORMATS:
             raise ValueError('Unsupported file format')
@@ -85,11 +85,11 @@ class Locator(object):
 
         >>> locator = Locator('john')
         >>> locator.suggestions_uri()
-        'http://my.gpodder.org/suggestions/10.opml'
+        'http://gpodder.net/suggestions/10.opml'
         >>> locator.suggestions_uri(50)
-        'http://my.gpodder.org/suggestions/50.opml'
+        'http://gpodder.net/suggestions/50.opml'
         >>> locator.suggestions_uri(70, 'json')
-        'http://my.gpodder.org/suggestions/70.json'
+        'http://gpodder.net/suggestions/70.json'
         """
         if format not in self.SIMPLE_FORMATS:
             raise ValueError('Unsupported file format')
@@ -102,11 +102,11 @@ class Locator(object):
 
         >>> locator = Locator(None)
         >>> locator.search_uri('outlaws')
-        'http://my.gpodder.org/search.opml?q=outlaws'
+        'http://gpodder.net/search.opml?q=outlaws'
         >>> locator.search_uri(':something?', 'txt')
-        'http://my.gpodder.org/search.txt?q=%3Asomething%3F'
+        'http://gpodder.net/search.txt?q=%3Asomething%3F'
         >>> locator.search_uri('software engineering', 'json')
-        'http://my.gpodder.org/search.json?q=software+engineering'
+        'http://gpodder.net/search.json?q=software+engineering'
         """
         if format not in self.SIMPLE_FORMATS:
             raise ValueError('Unsupported file format')
@@ -120,7 +120,7 @@ class Locator(object):
 
         >>> locator = Locator('bill')
         >>> locator.add_remove_subscriptions_uri('n810')
-        'http://my.gpodder.org/api/1/subscriptions/bill/n810.json'
+        'http://gpodder.net/api/1/subscriptions/bill/n810.json'
         """
         filename = '%(device_id)s.json' % locals()
         return util.join(self._base,
@@ -134,9 +134,9 @@ class Locator(object):
 
         >>> locator = Locator('jen')
         >>> locator.subscription_updates_uri('n900')
-        'http://my.gpodder.org/api/1/subscriptions/jen/n900.json'
+        'http://gpodder.net/api/1/subscriptions/jen/n900.json'
         >>> locator.subscription_updates_uri('n900', 1234)
-        'http://my.gpodder.org/api/1/subscriptions/jen/n900.json?since=1234'
+        'http://gpodder.net/api/1/subscriptions/jen/n900.json?since=1234'
         """
         filename = '%(device_id)s.json' % locals()
         if since is not None:
@@ -151,7 +151,7 @@ class Locator(object):
 
         >>> locator = Locator('thp')
         >>> locator.upload_episode_actions_uri()
-        'http://my.gpodder.org/api/1/episodes/thp.json'
+        'http://gpodder.net/api/1/episodes/thp.json'
         """
         filename = self._username + '.json'
         return util.join(self._base, 'episodes', filename)
@@ -170,17 +170,17 @@ class Locator(object):
 
         >>> locator = Locator('steve')
         >>> locator.download_episode_actions_uri()
-        'http://my.gpodder.org/api/1/episodes/steve.json'
+        'http://gpodder.net/api/1/episodes/steve.json'
         >>> locator.download_episode_actions_uri(since=1337)
-        'http://my.gpodder.org/api/1/episodes/steve.json?since=1337'
+        'http://gpodder.net/api/1/episodes/steve.json?since=1337'
         >>> locator.download_episode_actions_uri(podcast='http://example.org/episodes.rss')
-        'http://my.gpodder.org/api/1/episodes/steve.json?podcast=http%3A//example.org/episodes.rss'
+        'http://gpodder.net/api/1/episodes/steve.json?podcast=http%3A//example.org/episodes.rss'
         >>> locator.download_episode_actions_uri(since=2000, podcast='http://example.com/')
-        'http://my.gpodder.org/api/1/episodes/steve.json?since=2000&podcast=http%3A//example.com/'
+        'http://gpodder.net/api/1/episodes/steve.json?since=2000&podcast=http%3A//example.com/'
         >>> locator.download_episode_actions_uri(device_id='ipod')
-        'http://my.gpodder.org/api/1/episodes/steve.json?device=ipod'
+        'http://gpodder.net/api/1/episodes/steve.json?device=ipod'
         >>> locator.download_episode_actions_uri(since=54321, device_id='ipod')
-        'http://my.gpodder.org/api/1/episodes/steve.json?since=54321&device=ipod'
+        'http://gpodder.net/api/1/episodes/steve.json?since=54321&device=ipod'
         """
         if podcast is not None and device_id is not None:
             raise ValueError('must not specify both "podcast" and "device_id"')
@@ -208,7 +208,7 @@ class Locator(object):
 
         >>> locator = Locator('mike')
         >>> locator.device_settings_uri('ipod')
-        'http://my.gpodder.org/api/1/devices/mike/ipod.json'
+        'http://gpodder.net/api/1/devices/mike/ipod.json'
         """
         filename = '%(device_id)s.json' % locals()
         return util.join(self._base, 'devices', self._username, filename)
@@ -218,7 +218,7 @@ class Locator(object):
 
         >>> locator = Locator('jeff')
         >>> locator.device_list_uri()
-        'http://my.gpodder.org/api/1/devices/jeff.json'
+        'http://gpodder.net/api/1/devices/jeff.json'
         """
         filename = self._username + '.json'
         return util.join(self._base, 'devices', filename)
